@@ -457,6 +457,9 @@ class Component_V6(object):
 
         field = self.get_field(field_name)
         if field:
+            effects = find_by_key("effects", field["prop"])
+            if len(effects) == 0:
+                field["prop"].append([sexpdata.Symbol("effects")])
             effects = find_by_key("effects", field["prop"])[0]
             if effects:
                 try:
